<div class="modal fade" id="modalvow" tabindex="-1" role="dialog" aria-labelledby="modalvow" aria-hidden="true">
  <div class="modal-dialog modal-dialog-centered modal-fullscreen" role="document">
    <div class="modal-content">
      <div class="modal-body text-center">

        <img id="modalImage" src="" alt="Modal Image" class="img-fluid">
        <div class="modal-body text-center" id="imageText"></div>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-primary" data-bs-dismiss="modal">Close</button>
        <button type="button" class="btn btn-primary" id="prevImage">Previous</button>
        <button type="button" class="btn btn-primary" id="nextImage">Next</button>
      </div>
    </div>
  </div>
</div>
