{% load i18n %}
{% load navactive %}

<li class="nav-item">
    <a class="nav-link" href="{% url 'squads:pending' %}">Pending Requests{% if pending_count %} <span class="badge bg-secondary">{{ pending_count }}</span>{% endif %}</a>
</li>

<li class="nav-item">
    <a class="nav-link" href="{% url 'squads:membership' %}">My Memberships</a>
</li>

<li class="nav-item">
    <a class="nav-link" href="{% url 'squads:groups' %}">Browse Squads</a>
</li>
{% if perms.squads.admin_access or perms.squads.squad_manager %}
<li class="nav-item">
    <a class="nav-link" href="{% url 'squads:manage_groups' %}">Manage</a>
</li>
{% endif %}
