{% extends 'squads/base.html' %}
    {% load i18n %}
    {% load humanize %}

{% block squads_block %}
    <div class="card-title bg-primary rounded-top px-2"><h3>{% translate "Squads" %}</h3></div>
        <div class="card-body">
            Welcome to the Squads Page, here you can find all the squads that are available to join.
        </div>
    </div>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
